pub enum KeepSeparator {
Left,
Right,
}Expand description
How to handle separators when splitting.
Variants
Left
Include separator at the end of the preceding chunk.
Right
Include separator at the start of the following chunk.